pub enum InterpSegment {
Literal(String),
Expr(Box<Expr>),
}Expand description
A segment of an interpolated string in the AST.
Variants
Literal(String)
Literal text.
Expr(Box<Expr>)
A parsed expression to be evaluated and coerced to string.